package com.lzmispt.data.resource.service.resourceutil.impl;

package .tmp;

import com.alibaba.fastjson.JSONObject;
import com.lzmispt.core.client.MessageClient;
import com.lzmispt.core.entity.dto.message.MessageEntity;
import com.lzmispt.core.entity.dto.querymodel.QueryModelDTO;
import com.lzmispt.core.entity.dto.querymodel.SortModelDTO;
import com.lzmispt.core.entity.vo.sms.SendSmsResultVO;
import com.lzmispt.core.entity.vo.user.UserVO;
import com.lzmispt.data.center.entity.dto.databasestruct.DataSourceDTO;
import com.lzmispt.data.center.entity.dto.monitor.SendShortMessageDTO;
import com.lzmispt.data.center.entity.dto.querymodel.DCQueryModelDTO;
import com.lzmispt.data.center.entity.vo.resource.datasource.DataSourceVO;
import com.lzmispt.data.resource.client.CoreClient;
import com.lzmispt.data.resource.client.DataStandardClient;
import com.lzmispt.data.resource.entity.vo.monitor.WarningRecipientVo;
import com.lzmispt.data.resource.service.monitor.IMonitoringPlatformService;
import com.lzmispt.data.resource.service.resourceutil.ICommonFun;
import com.lzmispt.dcbase.databasestruct.DataStructProvider;
import com.lzmispt.dcbase.util.SmsLogUtil;
import com.lzmispt.framework.entity.entity.ResultEntity;
import com.lzmispt.framework.log.LogHelper;
import com.lzmispt.framework.utils.JedisUtil;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;
import org.springframework.util.ObjectUtils;

@Service
public class CommonFunImpl implements ICommonFun {
  @Autowired
  MessageClient messageClient;
  
  @Autowired
  CoreClient coreClient;
  
  @Autowired
  IMonitoringPlatformService monitoringPlatform;
  
  @Autowired
  JedisUtil jedisUtil;
  
  @Autowired
  DataStandardClient dataStandardClient;
  
  public <T> List<T> commonQuery(DCQueryModelDTO queryModelDTO, Class<T> clazz) {
    DataSourceVO dataSourceVO = (DataSourceVO)this.dataStandardClient.getDataSourceInfoDoNotDecryptByIdNotTokenId(queryModelDTO.getDataSourceId(), queryModelDTO.getPlatCode()).getObj();
    if (dataSourceVO != null) {
      DataSourceDTO dataSourceDTO = new DataSourceDTO();
      BeanUtils.copyProperties(dataSourceVO, dataSourceDTO);
      DataStructProvider dataStructProvider = (DataStructProvider)DataStructProvider.getDataBaseProvider(dataSourceDTO).getObj();
      return dataStructProvider.execCommonQuery((QueryModelDTO)queryModelDTO, clazz);
    } 
    return null;
  }
  
  public Boolean pushFrontEnd(Object object, String application, String user, String orgId) {
    JSONObject jsonBody = new JSONObject();
    jsonBody.put("msgCode", application);
    jsonBody.put("interfaceServiceMonitorPO", object);
    LogHelper.info("【数据推送监控向前端推送消息】" + jsonBody.toJSONString());
    sendMsg(jsonBody, application, user, orgId);
    return Boolean.valueOf(true);
  }
  
  public SendShortMessageDTO sendShort(String sendCode, Map<String, String> pram, String name, String token) {
    SendShortMessageDTO sendShortMessageDTO = new SendShortMessageDTO();
    List<String> numbers = new ArrayList<>();
    ResultEntity<List<WarningRecipientVo>> warningRecipient = this.monitoringPlatform.getWarningRecipientList("Statistics", "0");
    List<WarningRecipientVo> warningRecipientVos = (List<WarningRecipientVo>)warningRecipient.getObj();
    if (CollectionUtils.isEmpty(warningRecipientVos))
      return null; 
    for (WarningRecipientVo warningRecipientVo : warningRecipientVos) {
      UserVO user = getUser(warningRecipientVo.getUserId(), "0", null);
      numbers.add(user.getPhone());
    } 
    sendShortMessageDTO.setPhoneNumbers(numbers);
    sendShortMessageDTO.setTemplateParam(pram);
    sendShortMessageDTO.setSceneCode(sendCode);
    ResultEntity<SendSmsResultVO> stringResultEntity = this.coreClient.sendBySceneCode(sendShortMessageDTO, "Statistics", "0");
    SmsLogUtil.recordSmsSendLog(stringResultEntity, name, ((SendSmsResultVO)stringResultEntity.getObj()).getMessageContent(), token);
    return sendShortMessageDTO;
  }
  
  private void sendMsg(JSONObject jsonBody, String application, String userId, String orgId) {
    MessageEntity msg = new MessageEntity();
    msg.setId(userId);
    msg.setBody(jsonBody.toJSONString());
    msg.setApplication(application);
    msg.setOrganization(orgId);
    msg.setUser(userId);
    this.messageClient.sendTopicMessage(msg);
  }
  
  public List<String> getUserName() {
    List<String> list = new ArrayList<>();
    ResultEntity<List<WarningRecipientVo>> warningRecipientList = this.monitoringPlatform.getWarningRecipientList("Statistics", "0");
    for (WarningRecipientVo warningRecipientVo : warningRecipientList.getObj())
      list.add(warningRecipientVo.getUserName()); 
    return list;
  }
  
  public UserVO getUser(Long userId, String token, QueryModelDTO queryModelDTO) {
    return getUserVO(userId, token, queryModelDTO, this.coreClient);
  }
  
  public static UserVO getUserVO(Long userId, String token, QueryModelDTO queryModelDTO, CoreClient coreClient) {
    if (ObjectUtils.isEmpty(queryModelDTO)) {
      queryModelDTO = new QueryModelDTO();
      List<SortModelDTO> sortModelDTOS = new ArrayList<>();
      SortModelDTO sortModelDTO = new SortModelDTO();
      sortModelDTO.setFieldName("createTime");
      sortModelDTO.setSortType(Integer.valueOf(0));
      sortModelDTOS.add(sortModelDTO);
      queryModelDTO.setSortModels(sortModelDTOS);
    } 
    ResultEntity<List<UserVO>> userList = coreClient.getUserList(queryModelDTO, token);
    if (!ObjectUtils.isEmpty(userList.getObj())) {
      List<UserVO> userVOList = (List<UserVO>)userList.getObj();
      for (UserVO userVO : userVOList) {
        if (userVO.getMangerUserId().intValue() == userId.intValue())
          return userVO; 
      } 
    } 
    return null;
  }
}
